<?php

// require 'autoload.php';

// //Paramètres de base
// $token = 'test-467afe5eff145ffb2d87';

// $date = new DateTime();
// $dateFormat = $date->format('Ymd');
// var_dump($dateFormat);
// $publicKey = md5(uniqid('SparkWeb'));

// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);

// // // Init du service
// $service = new \SparkWebService(array('cache_wsdl' => WSDL_CACHE_NONE));

// // Méthode GetArticles
// // Init des paramètres
// $request = new \GetArticles($hashkey,$publicKey);

// // Récupération de la réponse
// // $response = $service->GetArticles($request);
// // var_dump($response);


// // Méthode GetArticle
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);

// $Code = "DGB18MGBRB01";
// $WebCode = "";

// //Appel de la requête
// $request = new \GetArticle($hashkey,$publicKey,$Code, $WebCode);

// // Récupération de la réponse
// // $response = $service->GetArticle($request);

// // var_dump($response);

// // Méthode UpdateArticle
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);

// $Code = "DGB18MGBRB01";
// $WebCode = "WEB-REF-DGB18MGBRB01";

// //Appel de la requête
// $request = new \UpdateArticle($hashkey,$publicKey,$Code, $WebCode);

// // Récupération de la réponse
// //$response = $service->UpdateArticle($request);

// //var_dump($response);


// // Méthode Createclient 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);

// $WebClientId = "WEB-CLIENT-02";
// $Email = "web-email@email.fr";
// $Civility = "1";
// $FirstName = "Robin";
// $LastName = "Delage";
// $BirthDate = $date;
// $LastUpdate = $date;
// $WebCreationDate = $date;
// $SiretNumber = '1212121212';
// $IntraComVat = '1010101010';
// $AddressLine1 = "AddressLine1";	
// $AddressLine2 = "AddressLine2";	
// $Building = "Building";		
// $PostalCode = "75000";		
// $City = "Paris";		
// $Country = "FR";		
// $PhoneNumber = "0606060606";	



// // Appel de la requête
// $request = new \CreateClient($hashkey,$publicKey, $WebClientId,$Email, $Civility, $FirstName, $LastName, $BirthDate, $LastUpdate, $WebCreationDate, $SiretNumber, $IntraComVat, $AddressLine1, $AddressLine2, $Building, $PostalCode, $City, $Country, $PhoneNumber);

// // Récupération de la réponse
// $response = $service->CreateClient($request);
// var_dump($response);


// // Méthode DoesClientExist
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);

// $Email = "web-email@email.fr";

// //Appel de la requête
// $request = new \DoesClientExist($hashkey,$publicKey,$Email);

// // Récupération de la réponse
// // $response = $service->DoesClientExist($request);
// // var_dump($response);

// // Méthode UpdateClient 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $ClientId = "10063034";
// $WebClientId = "WEB-CLIENT-02";
// $Civility = "1";
// $FirstName = "Nicolas";
// $LastName = "Martin";
// $BirthDate = $date;
// $LastUpdate = $date;
// $WebCreationDate = $date;
// $SiretNumber = 'Web siret2';
// $IntraComVat = 'Web intracomvat2';
// $IsInactive = '0';
// $AddressLine1 = "AddressLine1";	
// $AddressLine2 = "AddressLine2";	
// $Building = "Building";		
// $PostalCode = "75000";		
// $City = "Paris";		
// $Country = "FR";		
// $PhoneNumber = "0606060606";	

// Appel de la requête
// $request = new \UpdateClient($hashkey,$publicKey,$ClientId, $WebClientId, $Civility, $FirstName, $LastName, $BirthDate, $LastUpdate, $WebCreationDate, $SiretNumber, $IntraComVat,$AddressLine1, $AddressLine2, $Building, $PostalCode, $City, $Country, $PhoneNumber);

// // Récupération de la réponse
// // $response = $service->UpdateClient($request);
// // var_dump($response);


// // Méthode GetClient 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $WebClientId = "WEB-CLIENT-02";

// // Appel de la requête
// $request = new \GetClient($hashkey,$publicKey, $WebClientId);

// // Récupération de la réponse
// // $response = $service->GetClient($request);
// // var_dump($response);

// // Méthode CreateAddress 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $WebClientId = "WEB-CLIENT-02";
// $WebAddressId = "WEB-ADD-01";
// // 1	MONSIEUR
// // 2	MADAME
// // 3	DUCHESSE
// // 4	DUC
// // 5	SEIGNEUR
// // 6	ROI
// // 7	REINE
// // 8	DOCTEUR
// // 9	MAÎTRE
// // 10	COMTE
// // 11	STANDARD
// // 12	BARON
// $Civility = 1;
// $AddressAlias = "Nicolas Martin (livr)";
// $AddressLine1 = "Adresse 1";
// $AddressLine2 = "Adresse 2";
// $Building = "Batiment";
// $PostalCode = "75000";
// $City = "Paris";
// $Country = "FR";
// $PhoneNumber = "060606060606";
// $IntraComVat = "INTRACOMVAT";
// $SiretNumber = "SIRETNUMBER";
// $DeliveryComment ="Commentaire de livraison";
// $IsDeliveryAddress = "1";
// $IsBillingAddress = "1";
// $LastUpdate = $date;
// $WebCreationDate  = $date;

// // Appel de la requête
// $request = new \CreateAddress($hashkey,$publicKey, $WebClientId,
//                                 $WebAddressId,
//                                 $Civility,
//                                 $AddressAlias,
//                                 $AddressLine1,
//                                 $AddressLine2,
//                                 $Building,
//                                 $PostalCode,
//                                 $City,
//                                 $Country,
//                                 $PhoneNumber,
//                                 $IntraComVat,
//                                 $SiretNumber,
//                                 $DeliveryComment,
//                                 $IsDeliveryAddress,
//                                 $IsBillingAddress,
//                                 $LastUpdate,
//                                 $WebCreationDate
//                             );

// // Récupération de la réponse
// // $response = $service->CreateAddress($request);
// // var_dump($response);

// // Méthode UpdateAddress 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $WebClientId = "WEB-CLIENT-6";
// $WebAddressId = "WEB-ADD-4387";
// // 1	MONSIEUR
// // 2	MADAME
// // 3	DUCHESSE
// // 4	DUC
// // 5	SEIGNEUR
// // 6	ROI
// // 7	REINE
// // 8	DOCTEUR
// // 9	MAÎTRE
// // 10	COMTE
// // 11	STANDARD
// // 12	BARON
// $Civility = 1;
// $AddressAlias = "Luc Skywalker";
// $AddressLine1 = "38 rue du louveteau";
// $AddressLine2 = "Bat D";
// $Building = "";
// $PostalCode = "33000";
// $City = "Bordeaux";
// $Country = "FR";
// $PhoneNumber = "0606060606";
// $IntraComVat = "INTRACOMVAT";
// $SiretNumber = "SIRETNUMBER";
// $DeliveryComment ="Commentaire de livraison";
// $LastUpdate = $date;
// $WebCreationDate  = $date;

// // Appel de la requête
// $request = new \UpdateAddress($hashkey,$publicKey, $WebClientId,
//                                 $WebAddressId,
//                                 $Civility,
//                                 $AddressAlias,
//                                 $AddressLine1,
//                                 $AddressLine2,
//                                 $Building,
//                                 $PostalCode,
//                                 $City,
//                                 $Country,
//                                 $PhoneNumber,
//                                 $IntraComVat,
//                                 $SiretNumber,
//                                 $DeliveryComment,
//                                 $LastUpdate,
//                                 $WebCreationDate
//                             );

// // Récupération de la réponse
// $response = $service->UpdateAddress($request);
// var_dump($response);

// // Méthode GetAddress 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $WebClientId = "WEB-CLIENT-6";
// $WebAddressId = "WEB-ADD-4387";

// // Appel de la requête
// $request = new \GetAddress($hashkey,$publicKey, $WebClientId, $WebAddressId);

// // Récupération de la réponse
// // $response = $service->GetAddress($request);
// // var_dump($response);

// // Méthode CreateOrder 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $WebOrderId = "WEB-ORDER-03";
// $WebClientId = "WEB-CLIENT-02";
// $OrderDate = $date;
// $AddressAlias = "AddressAlias";
// $AddressLine1 = "AddressLine1";	
// $AddressLine2 = "AddressLine2";	
// $Building = "Building";		
// $PostalCode = "75000";		
// $City = "Paris";		
// $Country = "FR";		
// $PhoneNumber = "0606060606";	
// $DeliveryComment = "commentaire";


// // Appel de la requête
// $request = new \CreateOrder($hashkey,$publicKey, $WebOrderId, $WebClientId, $OrderDate,$AddressAlias, $AddressLine1, $AddressLine2, $Building, $PostalCode, $City, $Country, $PhoneNumber, $DeliveryComment);

// // Récupération de la réponse
// // $response = $service->CreateOrder($request);
// // var_dump($response);


// // Méthode CreateOrderLine 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $WebOrderId = "WEB-ORDER-03";
// $WebArticleId = "WEB-REF-DGB18MGBRB01";
// $UnitPriceET = "10";
// $UnitPriceIT = "12";
// $DiscountAmount = 0;
// $DiscountPercent = 0;
// $AmountET = "20";
// $AmountIT = "24";
// $Quantity = "2";
// $PromotionCode = "CODE-PROMO-01";
// $PromotionDescription = "Frais de port gratuits";
// // attention : instancier avec une date même si pas utilisé
// $PromotionValidityDate = $date;


// // Appel de la requête
// $request = new \CreateOrderLine($hashkey,$publicKey, $WebOrderId,
//                             $WebArticleId,
//                             $UnitPriceET,
//                             $UnitPriceIT,
//                             $DiscountAmount,
//                             $DiscountPercent,
//                             $Quantity,
//                             $AmountET,
//                             $AmountIT,
//                             $PromotionCode,
//                             $PromotionDescription,
//                             $PromotionValidityDate);

// // Récupération de la réponse
// // $response = $service->CreateOrderLine($request);
// // var_dump($response);

// // Méthode ValidateOrder 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $WebOrderId = "WEB-ORDER-03";
// $AmountET = "20";
// $AmountIT = "24";
// // 001	VIREMENT CA
// // 002	CHEQUES CA
// // 003	ESPECES CA
// // 004	TRAITE DOM CA
// // 005	TRAITE ACCEPTEE CA
// // 006	PAYPAL - WEEZ CA
// // 007	CARTE INTERNET CA
// // 008	AMEX CA
// // 009	CARTE BANCAIRE CA
// // 010	VAD CA
// // AM	AMEX
// // CB	CARTE BANCAIRE
// // CH	CHEQUE
// // ES	ESPECES
// // LR	TRAITE DOM
// // PP	PAYPAL
// // SCC	SOLDE CLT CREDITEUR (758)
// // SCD	SOLDE CLT DEBITEUR (658)
// // TA	TRAITE ACCEPTEE
// // VR	VIREMENT
// $PaymentMethod = "VCA";
// $PaymentId = "134hdkj3kjk34kdaoi3";
// // 10062508	DB SCHENKER	
// // 10062509	CALBERSON Mpl-GEODIS	
// // 10062510	COLLISIMO	
// // 10062511	CHRONOPOST	
// // 10075063	DHL	
// // 10078729	TRANSPORTEUR  - CLIENT	
// // 90000000	DAUMAS PRODUCTEUR	
// $Carrier = "10062508";
// $WebAddressId = "WEB-ADD-01";

// // Appel de la requête
// // $request = new \ValidateOrder($hashkey,$publicKey, $WebOrderId, $AmountET, $AmountIT, $PaymentMethod, $PaymentId, $Carrier, $WebAddressId);

// // Récupération de la réponse
// // $response = $service->ValidateOrder($request);
// // var_dump($response);


// // Méthode GetOrder 
// // Init des paramètres
// $publicKey = md5(uniqid('SparkWeb'));
// $key = $token . $publicKey .  $dateFormat;
// $hashkey = md5($key);
// $WebOrderId = "WEB-ORDER-01";


// // Appel de la requête
// $request = new \GetOrder($hashkey,$publicKey, $WebOrderId);

// // Récupération de la réponse
// // $response = $service->GetOrder($request);
// // var_dump($response);













